Input management — Kivy v1.0.1-dev documentation

# Input management

Our input system is wide and simple at the same time. We are currently able to support natively :

> - Windows multitouch event (pencil and finger)
> - MacOSX touchpad
> - Linux multitouch event (kernel and mtdev)
> - Linux wacom driver (pencil and finger)
> - TUIO

All the input management is configurable in the Kivy configuration. You can easily use many multitouch device into one Kivy application.

When the event have been read from devices, they are dispatched through post processing module, before sending them to your application. We got also several module by default for :

> - Double tap detection
> - Decrease jittering
> - Decrease the loose of touch on “bad” DIY hardware
> - Ignore regions

- Input Postprocessing
  - Dejitter
  - Double Tap
  - Ignore list
  - Retain Touch
- Providers
  - Native support of HID input from linux kernel
  - Native support of Wacom tablet from linuxwacom driver
  - Native support of MultitouchSupport framework for MacBook (MaxOSX platform)
  - Mouse provider implementation
  - Native support of Multitouch device on Linux, using libmtdev.
  - Auto Create Input Provider Config Entry for Available MT Hardware (linux only).
  - TUIO input provider implementation
  - Common definitions for Windows provider
  - Support of WM_PEN message (Window platform)
  - Support of WM_TOUCH message (Window platform)
- Motion Event Factory
- Motion Event
  - Motion Event and Touch
  - Listen to Motion Event
  - Profiles
- Motion Event Provider
- Motion Event Shape